package me.teridax.jcash.gui.transfer;

import me.teridax.jcash.Logging;
import me.teridax.jcash.banking.accounts.Account;
import me.teridax.jcash.banking.management.BankingManagementSystem;
import me.teridax.jcash.lang.Translator;

import static javax.swing.JOptionPane.ERROR_MESSAGE;
import static javax.swing.JOptionPane.showMessageDialog;
import static me.teridax.jcash.lang.Translator.translate;

public class TransferDialog {

    private final Account account;
    private final Runnable onDeposit;
    private final TransferData transferData;
    private final TransferView transferView;

    public TransferDialog(Account account, BankingManagementSystem bms, Runnable onDeposit) {
        this.account = account;
        this.onDeposit = onDeposit;

        transferView = new TransferView();
        transferData = new TransferData(bms);
        transferView.getTransfer().addActionListener(e -> transfer());
        transferView.getCancel().addActionListener(e -> transferView.dispose());
        transferView.showDialog();
    }

    private void transfer() {
        try {
            var amount = transferView.getAmount();

            account.takeoff(amount);
            transferData.transferValue(amount, transferView.getBlz(), transferView.getIban());
            onDeposit.run();
            transferView.dispose();
        } catch (IllegalArgumentException ex) {
            Logging.LOGGER.severe("Could not transfer: " + ex.getMessage());
            showMessageDialog(null, translate("Invalid account"), translate("Could not transfer"), ERROR_MESSAGE);
        }
    }
}
